@@ -225,7 +225,7 @@ init_get (gchar *command, get_data_t * get, const gchar *setting_name,
  */
 int
 get_next (iterator_t *resources, get_data_t *get, int *first, int *count,
-          int (*init) (iterator_t*, const get_data_t *))
+          int (*init) (iterator_t*, get_data_t *))
 {
   if (next (resources) == FALSE)
    {
@@ -323,12 +323,7 @@ send_get_common (const char *type, get_data_t *get, iterator_t *iterator,
                             "<%s id=\"%s\">"
                             "<owner><name>%s</name></owner>"
                             "<name>%s</name>"
-                            "<comment>%s</comment>"
-                            "<creation_time>%s</creation_time>"
-                            "<modification_time>%s</modification_time>"
-                            "<writable>%i</writable>"
-                            "<in_use>%i</in_use>"
-                            "<permissions>",
+                            "<comment>%s</comment>",
                             type,
                             get_iterator_uuid (iterator)
                             ? get_iterator_uuid (iterator)
@@ -341,13 +336,18 @@ send_get_common (const char *type, get_data_t *get, iterator_t *iterator,
                             : "",
                             get_iterator_comment (iterator)
                             ? get_iterator_comment (iterator)
-                            : "",
-                            get_iterator_creation_time (iterator)
-                            ? get_iterator_creation_time (iterator)
-                            : "",
-                            get_iterator_modification_time (iterator)
-                            ? get_iterator_modification_time (iterator)
-                            : "",
+                            : "");
+
+  buffer_xml_append_printf (buffer,
+                            "<creation_time>%s</creation_time>",
+                            iso_if_time (get_iterator_creation_time (iterator)));
+
+  buffer_xml_append_printf (buffer,
+                            "<modification_time>%s</modification_time>"
+                            "<writable>%i</writable>"
+                            "<in_use>%i</in_use>"
+                            "<permissions>",
+                            iso_if_time (get_iterator_modification_time (iterator)),
                             writable,
                             in_use);
 
