@@ -170,6 +170,7 @@ truncate_private_key (const gchar*);
 int
 get_certificate_info (const gchar *,
                       gssize,
+                      gboolean,
                       time_t *,
                       time_t *,
                       gchar **,
@@ -346,6 +347,8 @@ typedef resource_t tls_certificate_t;
 typedef resource_t result_t;
 typedef resource_t report_t;
 typedef resource_t report_host_t;
+typedef resource_t report_config_t;
+typedef resource_t report_config_param_t;
 typedef resource_t report_format_t;
 typedef resource_t report_format_param_t;
 typedef resource_t role_t;
@@ -628,7 +631,7 @@ int
 alert_count (const get_data_t *);
 
 int
-init_alert_iterator (iterator_t*, const get_data_t*);
+init_alert_iterator (iterator_t*, get_data_t*);
 
 int
 alert_iterator_event (iterator_t*);
@@ -728,7 +731,7 @@ unsigned int
 task_count (const get_data_t *);
 
 int
-init_task_iterator (iterator_t*, const get_data_t *);
+init_task_iterator (iterator_t*, get_data_t *);
 
 task_status_t
 task_iterator_run_status (iterator_t*);
@@ -835,6 +838,9 @@ set_task_hosts_ordering (task_t, const char *);
 void
 set_task_scanner (task_t, scanner_t);
 
+int
+task_usage_type (task_t, char**);
+
 void
 set_task_usage_type (task_t, const char *);
 
@@ -1169,9 +1175,6 @@ result_detection_reference (result_t, report_t, const char *, const char *,
 
 /* Reports. */
 
-/** @todo How is this documented? */
-#define OVAS_MANAGE_REPORT_ID_LENGTH UUID_LEN_STR
-
 /**
  * @brief Default apply_overrides setting
  */
@@ -1285,7 +1288,7 @@ insert_report_host_detail (report_t, const char *, const char *, const char *,
                            const char *);
 
 int
-manage_report_host_detail (report_t, const char *, const char *);
+manage_report_host_detail (report_t, const char *, const char *, GHashTable *);
 
 void
 hosts_set_identifiers (report_t);
@@ -1328,7 +1331,7 @@ gboolean
 report_task (report_t, task_t*);
 
 void
-report_compliance_by_uuid (const char *, int *, int *, int *);
+report_compliance_by_uuid (const char *, int *, int *, int *, int *);
 
 int
 report_scan_result_count (report_t, const char*, const char*, int, const char*,
@@ -1412,6 +1415,8 @@ result_count (const get_data_t *, report_t, const char*);
 int
 init_result_get_iterator (iterator_t*, const get_data_t *, report_t,
                           const char*, const gchar *);
+int
+init_result_get_iterator_all (iterator_t* iterator, get_data_t *get);                         
 
 gboolean
 next_report (iterator_t*, report_t*);
@@ -1521,12 +1526,39 @@ result_iterator_may_have_overrides (iterator_t*);
 int
 result_iterator_may_have_tickets (iterator_t*);
 
+double
+result_iterator_epss_score (iterator_t*);
+
+double
+result_iterator_epss_percentile (iterator_t*);
+
+const char*
+result_iterator_epss_cve (iterator_t*);
+
+double
+result_iterator_epss_severity (iterator_t*);
+
+double
+result_iterator_max_epss_score (iterator_t*);
+
+double
+result_iterator_max_epss_percentile (iterator_t*);
+
+const char*
+result_iterator_max_epss_cve (iterator_t*);
+
+double
+result_iterator_max_epss_severity (iterator_t*);
+
 gchar **
 result_iterator_cert_bunds (iterator_t*);
 
 gchar **
 result_iterator_dfn_certs (iterator_t*);
 
+const char *
+result_iterator_compliance (iterator_t*);
+
 const char *
 result_iterator_delta_state (iterator_t*);
 
@@ -1539,6 +1571,9 @@ result_iterator_delta_severity (iterator_t*);
 double
 result_iterator_delta_severity_double (iterator_t*);
 
+const char *
+result_iterator_delta_compliance (iterator_t*);
+
 const char*
 result_iterator_delta_level (iterator_t*);
 
@@ -1560,10 +1595,10 @@ result_iterator_delta_uuid (iterator_t*);
 const char *
 result_iterator_delta_qod_type (iterator_t*);
 
-const char *
+time_t
 result_iterator_delta_creation_time (iterator_t*);
 
-const char *
+time_t
 result_iterator_delta_modification_time (iterator_t*);
 
 task_t
@@ -1630,12 +1665,14 @@ int
 report_progress (report_t);
 
 gchar *
-manage_report (report_t, report_t, const get_data_t *, report_format_t,
+manage_report (report_t, report_t, const get_data_t *,
+               report_format_t, report_config_t,
                int, int, gsize *, gchar **, gchar **, gchar **, gchar **,
                gchar **);
 
 int
-manage_send_report (report_t, report_t, report_format_t, const get_data_t *,
+manage_send_report (report_t, report_t, report_format_t, report_config_t,
+                    const get_data_t *,
                     int, int, int, int, int, int,
                     gboolean (*) (const char *,
                                   int (*) (const char*, void*),
@@ -1696,8 +1733,8 @@ manage_filter_controls (const gchar *, int *, int *, gchar **, int *);
 
 void
 manage_report_filter_controls (const gchar *, int *, int *, gchar **, int *,
-                               int *, gchar **, gchar **, gchar **, gchar **,
-                               int *, int *, int *, int *, gchar **);
+                               int *, gchar **, gchar **, gchar **, gchar **, 
+                               gchar **, int *, int *, int *, int *, gchar **);
 
 gchar *
 manage_clean_filter (const gchar *);
@@ -1740,7 +1777,7 @@ void
 init_target_iterator_one (iterator_t*, target_t);
 
 int
-init_target_iterator (iterator_t*, const get_data_t *);
+init_target_iterator (iterator_t*, get_data_t *);
 
 const char*
 target_iterator_hosts (iterator_t*);
@@ -1909,6 +1946,9 @@ find_nvt (const char*, nvt_t*);
 int
 init_nvt_info_iterator (iterator_t*, get_data_t*, const char*);
 
+int
+init_nvt_info_iterator_all (iterator_t*, get_data_t*);
+
 int
 nvt_info_count (const get_data_t *);
 
@@ -1976,6 +2016,36 @@ nvt_iterator_solution_type (iterator_t*);
 const char*
 nvt_iterator_solution_method (iterator_t*);
 
+double
+nvt_iterator_epss_score (iterator_t*);
+
+double
+nvt_iterator_epss_percentile (iterator_t*);
+
+const char*
+nvt_iterator_epss_cve (iterator_t*);
+
+double
+nvt_iterator_epss_severity (iterator_t*);
+
+gboolean
+nvt_iterator_has_epss_severity (iterator_t*);
+
+double
+nvt_iterator_max_epss_score (iterator_t*);
+
+double
+nvt_iterator_max_epss_percentile (iterator_t*);
+
+const char*
+nvt_iterator_max_epss_cve (iterator_t*);
+
+double
+nvt_iterator_max_epss_severity (iterator_t*);
+
+gboolean
+nvt_iterator_has_max_epss_severity (iterator_t*);
+
 char*
 nvt_default_timeout (const char *);
 
@@ -2176,7 +2246,7 @@ void
 init_credential_iterator_one (iterator_t*, credential_t);
 
 int
-init_credential_iterator (iterator_t*, const get_data_t *);
+init_credential_iterator (iterator_t*, get_data_t *);
 
 const char*
 credential_iterator_login (iterator_t*);
@@ -2330,6 +2400,9 @@ host_identifier_iterator_os_title (iterator_t *);
 int
 init_asset_host_iterator (iterator_t *, const get_data_t *);
 
+int
+init_resource_names_host_iterator (iterator_t *iterator, get_data_t *get);
+
 int
 asset_iterator_writable (iterator_t *);
 
@@ -2345,6 +2418,9 @@ asset_host_count (const get_data_t *);
 int
 init_asset_os_iterator (iterator_t *, const get_data_t *);
 
+int
+init_resource_names_os_iterator (iterator_t *, get_data_t *);
+
 const char*
 asset_os_iterator_title (iterator_t *);
 
@@ -2435,6 +2511,9 @@ note_count (const get_data_t *, nvt_t, result_t, task_t);
 int
 init_note_iterator (iterator_t*, const get_data_t*, nvt_t, result_t, task_t);
 
+int
+init_note_iterator_all (iterator_t* iterator, get_data_t *get);
+
 const char*
 note_iterator_nvt_oid (iterator_t*);
 
@@ -2509,6 +2588,9 @@ int
 init_override_iterator (iterator_t*, const get_data_t*, nvt_t, result_t,
                         task_t);
 
+int
+init_override_iterator_all (iterator_t* iterator, get_data_t *get);                        
+
 const char*
 override_iterator_nvt_oid (iterator_t*);
 
@@ -2682,7 +2764,7 @@ char *
 openvas_default_scanner_host ();
 
 int
-init_scanner_iterator (iterator_t*, const get_data_t *);
+init_scanner_iterator (iterator_t*, get_data_t *);
 
 const char*
 scanner_iterator_host (iterator_t*);
@@ -2832,7 +2914,7 @@ void
 set_scheduled_user_uuid (const gchar* uuid);
 
 void
-manage_sync (sigset_t *, int (*fork_update_nvt_cache) (), gboolean);
+manage_sync (sigset_t *, int (*fork_update_nvt_cache) (pid_t*), gboolean);
 
 int
 manage_rebuild_gvmd_data_from_feed (const char *,
@@ -2867,7 +2949,7 @@ int
 schedule_info (schedule_t, int, gchar **, gchar **);
 
 int
-init_schedule_iterator (iterator_t*, const get_data_t *);
+init_schedule_iterator (iterator_t*, get_data_t *);
 
 const char*
 schedule_iterator_timezone (iterator_t *);
@@ -2919,7 +3001,7 @@ set_schedule_timeout (int);
 /* Groups. */
 
 int
-init_group_iterator (iterator_t *, const get_data_t *);
+init_group_iterator (iterator_t *, get_data_t *);
 
 int
 copy_group (const char *, const char *, const char *, group_t *);
@@ -2986,7 +3068,7 @@ int
 permission_count (const get_data_t *);
 
 int
-init_permission_iterator (iterator_t*, const get_data_t *);
+init_permission_iterator (iterator_t*, get_data_t *);
 
 const char*
 permission_iterator_resource_type (iterator_t*);
@@ -3043,7 +3125,7 @@ int
 manage_get_roles (GSList *, const db_conn_info_t *, int);
 
 int
-init_role_iterator (iterator_t *, const get_data_t *);
+init_role_iterator (iterator_t *, get_data_t *);
 
 int
 copy_role (const char *, const char *, const char *, role_t *);
@@ -3200,7 +3282,7 @@ int
 filter_count (const get_data_t*);
 
 int
-init_filter_iterator (iterator_t*, const get_data_t*);
+init_filter_iterator (iterator_t*, get_data_t*);
 
 const char*
 filter_iterator_type (iterator_t*);
@@ -3263,6 +3345,9 @@ init_cpe_cve_iterator (iterator_t *, const char *, int, const char *);
 int
 init_cpe_info_iterator (iterator_t*, get_data_t*, const char*);
 
+int
+init_cpe_info_iterator_all (iterator_t*, get_data_t*);
+
 int
 cpe_info_count (const get_data_t *get);
 
@@ -3307,9 +3392,19 @@ cve_info_iterator_description (iterator_t*);
 const char*
 cve_info_iterator_products (iterator_t*);
 
+double
+cve_info_iterator_epss_score (iterator_t*);
+
+double
+cve_info_iterator_epss_percentile (iterator_t*);
+
 int
 init_cve_info_iterator (iterator_t*, get_data_t*, const char*);
 
+
+int
+init_cve_info_iterator_all (iterator_t*, get_data_t*);
+
 int
 cve_info_count (const get_data_t *get);
 
@@ -3325,6 +3420,9 @@ manage_cert_loaded ();
 int
 init_cert_bund_adv_info_iterator (iterator_t*, get_data_t*, const char*);
 
+int
+init_cert_bund_adv_info_iterator_all (iterator_t*, get_data_t*);
+
 int
 cert_bund_adv_info_count (const get_data_t *get);
 
@@ -3354,6 +3452,9 @@ nvt_cert_bund_adv_iterator_name (iterator_t*);
 int
 init_dfn_cert_adv_info_iterator (iterator_t*, get_data_t*, const char*);
 
+int
+init_dfn_cert_adv_info_iterator_all (iterator_t*, get_data_t*);
+
 int
 dfn_cert_adv_info_count (const get_data_t *get);
 
@@ -3417,6 +3518,9 @@ setting_iterator_comment (iterator_t*);
 const char*
 setting_iterator_value (iterator_t*);
 
+int
+setting_value_int (const char *, int *);
+
 int
 modify_setting (const gchar *, const gchar *, const gchar *, gchar **);
 
@@ -3476,7 +3580,7 @@ gchar *
 keyfile_to_auth_conf_settings_xml (const gchar *);
 
 int
-init_user_iterator (iterator_t*, const get_data_t*);
+init_user_iterator (iterator_t*, get_data_t*);
 
 const char*
 user_iterator_role (iterator_t*);
@@ -3520,7 +3624,7 @@ create_user (const gchar *, const gchar *, const gchar *, const gchar *,
              array_t *, gchar **, gchar **, user_t *, int);
 
 int
-delete_user (const char *, const char *, int, int, const char*, const char*);
+delete_user (const char *, const char *, int, const char*, const char*);
 
 int
 modify_user (const gchar *, gchar **, const gchar *, const gchar *,
@@ -3622,7 +3726,7 @@ modify_tag (const char *, const char *, const char *, const char *,
             gchar **);
 
 int
-init_tag_iterator (iterator_t*, const get_data_t*);
+init_tag_iterator (iterator_t*, get_data_t*);
 
 int
 tag_count (const get_data_t *get);
@@ -3655,7 +3759,7 @@ int
 tag_resource_iterator_readable (iterator_t*);
 
 int
-init_tag_name_iterator (iterator_t*, const get_data_t*);
+init_tag_name_iterator (iterator_t*, get_data_t*);
 
 const char*
 tag_name_iterator_name (iterator_t*);
@@ -3776,6 +3880,27 @@ get_feed_lock_timeout ();
 void
 set_feed_lock_timeout (int);
 
+int
+get_max_concurrent_scan_updates ();
+
+void
+set_max_concurrent_scan_updates (int);
+
+int
+get_mem_wait_retries ();
+
+void
+set_mem_wait_retries (int);
+
+int
+check_min_mem_feed_update ();
+
+int
+get_min_mem_feed_update ();
+
+void
+set_min_mem_feed_update (int);
+
 void
 write_sync_start (int);
 
