@@ -47,6 +47,7 @@
 #include <sys/file.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/wait.h>
 #include <unistd.h>
 
 #include <gvm/base/gvm_sentry.h>
@@ -483,7 +484,7 @@ iso_time_internal (time_t *epoch_time, const char **abbrev)
 /**
  * @brief Create an ISO time from seconds since epoch.
  *
- * @param[in]  epoch_time  Time in seconds from epoch.
+ * @param[in]  epoch_time  Pointer to time in seconds from epoch.
  *
  * @return Pointer to ISO time in static memory, or NULL on error.
  */
@@ -496,7 +497,7 @@ iso_time (time_t *epoch_time)
 /**
  * @brief Create an ISO time from seconds since epoch, given a timezone.
  *
- * @param[in]  epoch_time  Time in seconds from epoch.
+ * @param[in]  epoch_time  Pointer to time in seconds from epoch.
  * @param[in]  zone        Timezone.
  * @param[out] abbrev      Timezone abbreviation.
  *
@@ -543,6 +544,28 @@ iso_time_tz (time_t *epoch_time, const char *zone, const char **abbrev)
   return ret;
 }
 
+/**
+ * @brief Create an ISO time from seconds since epoch, with a 0 check.
+ *
+ * @param[in]  epoch_time  Time in seconds from epoch.
+ *
+ * @return ISO time string in static memory.  If epoch_time is 0 then string is empty.
+ */
+char *
+iso_if_time (time_t epoch_time)
+{
+  static char *empty = "";
+  if (epoch_time)
+    {
+      char *ret;
+
+      ret = iso_time (&epoch_time);
+      if (ret)
+        return ret;
+    }
+  return empty;
+}
+
 
 /* Locks. */
 
@@ -747,6 +770,73 @@ is_uuid (const char *uuid)
   return 1;
 }
 
+
+/* Strings. */
+
+/**
+ * @brief Escape a string with exceptions for UTF-8 if it is valid UTF-8.
+ *
+ * If the string is valid UTF-8, characters in the range 0x80 - 0xFF
+ * are excluded so non-ASCII UTF-8 characters and any characters in the
+ * extra_exceptions are not escaped.
+ * This leaves the characters 0x01 - 0x1F and 0x7F to be escaped if they are
+ * not in the given extra_exceptions.
+ *
+ * For strings that are not valid UTF-8 all characters in the ranges
+ *
+ * @param[in]  str               The string to escape.
+ * @param[in]  extra_exceptions  Extra exc.
+ *
+ * @return Newly allocated escaped copy of the string.
+ */
+gchar *
+strescape_check_utf8 (const char *str, const char *extra_exceptions)
+{
+  if (g_utf8_validate (str, -1, NULL))
+    return strescape_without_utf8 (str, extra_exceptions);
+  else
+    return g_strescape (str, extra_exceptions);
+}
+
+/**
+ * @brief Escape control characters in a string with exceptions for UTF-8.
+ *
+ * Characters in the range 0x80 - 0xFF are excluded so non-ASCII UTF-8
+ * characters are not escaped.
+ * This leaves the characters 0x01 - 0x1F and 0x7F to be escaped if they are
+ * not in the given extra_exceptions.
+ *
+ * @param[in]  str               The string to escape.
+ * @param[in]  extra_exceptions  Extra exceptions to the escaping.
+ *
+ * @return Newly allocated escaped copy of the string.
+ */
+gchar *
+strescape_without_utf8 (const char *str, const char *extra_exceptions)
+{
+  static const char *base_exceptions =
+    "\200\201\202\203\204\205\206\207\210\211\212\213\214\215\216\217"
+    "\220\221\222\223\224\225\226\227\230\231\232\233\234\235\236\237"
+    "\240\241\242\243\244\245\246\247\250\251\252\253\254\255\256\257"
+    "\260\261\262\263\264\265\266\267\270\271\272\273\274\275\276\277"
+    "\300\301\302\303\304\305\306\307\310\311\312\313\314\315\316\317"
+    "\320\321\322\323\324\325\326\327\330\331\332\333\334\335\336\337"
+    "\340\341\342\343\344\345\346\347\350\351\352\353\354\355\356\357"
+    "\360\361\362\363\364\365\366\367\370\371\372\373\374\375\376\377";
+  gchar *exceptions = NULL;
+  gchar *escaped;
+
+  if (extra_exceptions && strcmp (extra_exceptions, ""))
+    {
+      exceptions = g_strconcat (base_exceptions,
+                                extra_exceptions ? extra_exceptions : "",
+                                NULL);
+    }
+  escaped = g_strescape (str, exceptions ? exceptions : base_exceptions);
+  g_free (exceptions);
+  return escaped;
+}
+
 
 /* XML. */
 
@@ -884,3 +974,78 @@ fork_with_handlers ()
     }
   return pid;
 }
+
+/**
+ * @brief Waits for a process with the given PID, retrying if interrupted.
+ *
+ * If the wait is interrupted or the process does not exist, only debug
+ *  messages are logged.
+ *
+ * @param[in]  pid      The pid to wait for.
+ * @param[in]  context  Short context desciption for error and debug messages.
+ */
+void
+wait_for_pid (pid_t pid, const char *context)
+{
+  gboolean retry = TRUE;
+  const char *shown_context = context ? context : "unknown context";
+  if (pid <= 0)
+    {
+      g_message ("%s: No PID given (%s)", __func__, shown_context);
+      return;
+    }
+
+  while (retry)
+    {
+      retry = FALSE;
+      pid_t ret = waitpid (pid, NULL, 0);
+      if (ret <= 0)
+        {
+          int err = errno;
+          if (errno == ECHILD)
+            {
+              g_debug ("%s: process with PID %d (%s) does not exist",
+                       __func__, pid, shown_context);
+            }
+          else if (errno == EINTR)
+            {
+              g_debug ("%s: waitpid interrupted for PID %d (%s), retrying...",
+                       __func__, pid, shown_context);
+              retry = TRUE;
+            }
+          else
+            {
+              g_warning ("%s: waitpid failed for PID %d (%s): %s",
+                         __func__, pid, shown_context, strerror(err));
+            }
+        }
+      else
+        {
+          g_debug ("%s: wait for PID %d (%s) successful",
+                   __func__, pid, shown_context);
+        }
+    }
+}
+
+/**
+ * @brief Get the available physical memory in bytes.
+ * 
+ * @return The available memory
+ */
+guint64
+phys_mem_available ()
+{
+  return (unsigned long long)(sysconf(_SC_AVPHYS_PAGES))
+    * sysconf(_SC_PAGESIZE);
+}
+
+/**
+ * @brief Get the total physical memory in bytes.
+ * 
+ * @return The total memory
+ */
+guint64
+phys_mem_total ()
+{
+  return sysconf(_SC_PHYS_PAGES) * sysconf(_SC_PAGESIZE);
+}
